'use strict';

module.exports = function (tableComponent, resizeObj, columnWidths) {

  function getSizeOfElements(ids) {
    if (!(ids && ids.length)) return 0;
    var total = 0;
    ids.forEach(function (id) {
      var elem = document.getElementById(id);
      if (elem && elem.offsetHeight) {
        total += elem.offsetHeight;
      }
    });
    return total;
  }

  var id = tableComponent.id;
  var extra = 0;
  var minSize = 0;

  if (typeof resizeObj.minSize === 'number') {
    minSize = resizeObj.minSize;
  }

  if (typeof resizeObj.extra === 'number') {
    extra = resizeObj.extra;
  }
  if (resizeObj.elements && resizeObj.elements.length) {
    extra = extra + getSizeOfElements(resizeObj.elements);
  }
  if (extra) {
    var headerElement = document.getElementById(tableComponent.headerId);
    if (headerElement) {
      extra = extra + headerElement.offsetHeight;
    }
  }

  function resize() {
    var h = window.innerHeight;
    var table = document.getElementById(tableComponent.id);
    var tableBody = document.getElementById(tableComponent.bodyId);
    if (!table) {
      return;
    }

    var th = table.offsetHeight;
    var tw = table.width;
    if (extra) {
      th = h - extra;
    }
    if (th < minSize) {
      th = minSize;
    }
    tableBody.style.height = '' + th + 'px';

    tableComponent.props.columns.forEach(function (col) {
      var width = columnWidths.getSize(tw, col.name) + extra;
      var className = 'cbst-' + col.name;
      console.log('COL ' + col.name + ' width = ' + width);

      var cols = document.getElementsByClassName(className);
      for (var i = 0; i < cols.length; i++) {
        var _col = cols[i];
        _col.style.width = '' + width + 'px';
      }
    });
  }

  this.addHandler = function () {
    window.addEventListener('resize', resize);
    resize();
  };

  this.removeHandler = function () {
    document.body.removeEventListener('resize', resize);
  };
};